Module and Class Hierarchies

[show private | hide private]
[frames | no frames]

## Module Hierarchy

- `sqltriples`: A simple SQL-accessible RDF triple store.
  - `Adapters`: Database-specific adapter classes.
  - `Query`: Database querying classes.
  - `Store`: RDF triple store classes.
  - `Types`: Special data types inheriting from the unicode type in order to provide interoperability with rdflib.

## Class Hierarchy

- `__builtin__.object`: The most base type
  - `__builtin__.basestring`: Type basestring cannot be instantiated; it is the base for str and unicode.
    - `__builtin__.unicode`: unicode(string [, encoding[, errors]]) -> object
      - `sqltriples.Types.Special`
        - `sqltriples.Types.Literal`: A literal compatible with the rdflib class of the same name.
        - `sqltriples.Types.URIRef`: An URI reference compatible with the rdflib class of the same name.
          - `sqltriples.Types.Namespace`: A namespace compatible with the rdflib class of the same name.
  - `__builtin__.type`: type(object) -> the object's type type(name, bases, dict) -> a new type
- `exceptions.Exception`: Common base class for all exceptions.
  - `sqltriples.Query.NotSupportedError`
- `sqltriples.Adapters.Adapter`
  - `sqltriples.Adapters.PgSQLAdapter`
  - `sqltriples.Adapters.pysqlite2Adapter`
- `sqltriples.Query.AbstractQuery`
  - `sqltriples.Query.Query`: An abstract class providing support for lazy query evaluation.
    - `sqltriples.Query.Results`: A class representing a selection of results obtained by specifying a pattern.
      - `sqltriples.Query.CountableResults`: A class representing a count of some results.
      - `sqltriples.Query.SingleResults`: A class representing a selection of single value results.
        - `sqltriples.Query.Objects`: A class representing a selection of objects.
          - `sqltriples.Query.ConjunctionOfObjects`
          - `sqltriples.Query.DisjunctionOfObjects`
          - `sqltriples.Query.IntersectionOfObjects`
          - `sqltriples.Query.NegationOfObjects`
        - `sqltriples.Query.Predicates`: A class representing a selection of predicates.
          - `sqltriples.Query.ConjunctionOfPredicates`
          - `sqltriples.Query.DisjunctionOfPredicates`
          - `sqltriples.Query.IntersectionOfPredicates`
          - `sqltriples.Query.NegationOfPredicates`
        - `sqltriples.Query.Subjects`: A class representing a selection of subjects.
          - `sqltriples.Query.ConjunctionOfSubjects`
          - `sqltriples.Query.DisjunctionOfSubjects`
          - `sqltriples.Query.IntersectionOfSubjects`
          - `sqltriples.Query.NegationOfSubjects`
      - `sqltriples.Query.Triples`: A class representing a selection of triples.
        - `sqltriples.Query.ConjunctionOfTriples`
        - `sqltriples.Query.DisjunctionOfTriples`
        - `sqltriples.Query.IntersectionOfTriples`
        - `sqltriples.Query.NegationOfTriples`
      - `sqltriples.Query.Tuples`: A class representing a selection of triples.
        - `sqltriples.Query.ConjunctionOfTuples`
        - `sqltriples.Query.DisjunctionOfTuples`
        - `sqltriples.Query.IntersectionOfTuples`
        - `sqltriples.Query.NegationOfTuples`
  - `sqltriples.Query.Subject`: A class representing a more conveniently accessible subject.
- `sqltriples.Query.CombinedResults`
  - `sqltriples.Query.CombinedTopLevelResults`
    - `sqltriples.Query.Intersection`
      - `sqltriples.Query.IntersectionOfObjects`
      - `sqltriples.Query.IntersectionOfPredicates`
      - `sqltriples.Query.IntersectionOfSubjects`
      - `sqltriples.Query.IntersectionOfTriples`
      - `sqltriples.Query.IntersectionOfTuples`
  - `sqltriples.Query.Conjunction`
    - `sqltriples.Query.ConjunctionOfObjects`
    - `sqltriples.Query.ConjunctionOfPredicates`
    - `sqltriples.Query.ConjunctionOfSubjects`
    - `sqltriples.Query.ConjunctionOfTriples`
    - `sqltriples.Query.ConjunctionOfTuples`
  - `sqltriples.Query.Disjunction`
    - `sqltriples.Query.DisjunctionOfObjects`
    - `sqltriples.Query.DisjunctionOfPredicates`
    - `sqltriples.Query.DisjunctionOfSubjects`
    - `sqltriples.Query.DisjunctionOfTriples`
    - `sqltriples.Query.DisjunctionOfTuples`
- `sqltriples.Query.Negation`: A class representing the negation of other results.
  - `sqltriples.Query.NegationOfObjects`
  - `sqltriples.Query.NegationOfPredicates`
  - `sqltriples.Query.NegationOfSubjects`
  - `sqltriples.Query.NegationOfTriples`
  - `sqltriples.Query.NegationOfTuples`
- `sqltriples.Store.TripleStore`: A triple store whose contents are stored in an SQL-accessible database table.
- `sqltriples.Types.AbstractExpression`
  - `sqltriples.Types.Expression`
- `sqltriples.Types.BNode`: A BNode compatible with the rdflib class of the same name.
- `sqltriples.Types.Defined`: A class indicating a value defined for a particular relation.
- `sqltriples.Types.Pattern`

Generated by Epydoc 2.1 on Sat Sep 30 00:54:37 2006 | http://epydoc.sf.net